@@ -11,10 +11,12 @@ A brainfuck toolbox for python.
 
 from .core import *
 from .enums import *
-from .parser import *
+from .compiler import *
+from .encoder import *
+from .tools import *
 
 __title__ = 'bftools'
 __author__ = 'BobDotCom'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2021 BobDotCom'
-__version__ = '0.0.2'
+__version__ = '0.1.0'
